@@ -20,7 +20,6 @@ static void GTIFPrintCorners( GTIF *, GTIFDefn *, FILE *, int, int, int, int );
 static TIFF *st_setup_test_info();
 
 void Usage()
-
 {
     printf( 
         "%s", 
@@ -28,7 +27,7 @@ void Usage()
         "\n"
         "  -d: report lat/long corners in decimal degrees instead of DMS.\n"
         "  -tfw: Generate a .tfw (ESRI TIFF World) file for the target file.\n"
-        "  -proj4: Report PROJ.4 equivelent projection definition.\n"
+        "  -proj4: Report PROJ.4 equivalent projection definition.\n"
         "  -no_norm: Don't report 'normalized' parameter values.\n"
         "  filename: Name of the GeoTIFF file to report on.\n" );
         
@@ -198,8 +197,16 @@ static int GTIFReportACorner( GTIF *gtif, GTIFDefn *defn, FILE * fp_out,
 	    } 
 	    else 
 	    {
-		fprintf( fp_out, "  (%s,", GTIFDecToDMS( x, "Long", 2 ) );
-		fprintf( fp_out, "%s)", GTIFDecToDMS( y, "Lat", 2 ) );
+                const char* pszLong = GTIFDecToDMS( x, "Long", 2 );
+                if( pszLong[0] == 0 )
+                {
+                    fprintf( fp_out, "  (invalid)" );
+                }
+                else
+                {
+                    fprintf( fp_out, "  (%s,", pszLong );
+                    fprintf( fp_out, "%s)", GTIFDecToDMS( y, "Lat", 2 ) );
+                }
 	    }
         }
 
@@ -219,20 +226,29 @@ static void GTIFPrintCorners( GTIF *gtif, GTIFDefn *defn, FILE * fp_out,
 
 {
     printf( "\nCorner Coordinates:\n" );
+
+    unsigned short raster_type = RasterPixelIsArea;
+    GTIFKeyGetSHORT(gtif, GTRasterTypeGeoKey, &raster_type, 0, 1);
+
+    double xmin = (raster_type == RasterPixelIsArea) ? 0.0 : -0.5;
+    double ymin = xmin;
+    double ymax = ymin + ysize;
+    double xmax = xmin + xsize;
+
     if( !GTIFReportACorner( gtif, defn, fp_out,
-                            "Upper Left", 0.0, 0.0, inv_flag, dec_flag ) )
+                            "Upper Left", xmin, ymin, inv_flag, dec_flag ) )
     {
         printf( " ... unable to transform points between pixel/line and PCS space\n" );
         return;
     }
 
-    GTIFReportACorner( gtif, defn, fp_out, "Lower Left", 0.0, ysize, 
+    GTIFReportACorner( gtif, defn, fp_out, "Lower Left", xmin, ymax,
                        inv_flag, dec_flag );
-    GTIFReportACorner( gtif, defn, fp_out, "Upper Right", xsize, 0.0,
+    GTIFReportACorner( gtif, defn, fp_out, "Upper Right", xmax, ymin,
                        inv_flag, dec_flag );
-    GTIFReportACorner( gtif, defn, fp_out, "Lower Right", xsize, ysize,
+    GTIFReportACorner( gtif, defn, fp_out, "Lower Right", xmax, ymax,
                        inv_flag, dec_flag );
-    GTIFReportACorner( gtif, defn, fp_out, "Center", xsize/2.0, ysize/2.0,
+    GTIFReportACorner( gtif, defn, fp_out, "Center", xmin + xsize/2.0, ymin + ysize/2.0,
                        inv_flag, dec_flag );
 }
 
